#19855: restore use of LC_ALL, not LC_MESSAGES

I didn't realize LC_ALL was an override, and I should have.  I tried to
make a test, but it is not clear that the LC variables actually affect
the strings that uuid is using to parse the command output.
diff --git a/Lib/uuid.py b/Lib/uuid.py
index 2a70ce6..63cb3ae 100644
--- a/Lib/uuid.py
+++ b/Lib/uuid.py
@@ -305,9 +305,9 @@
         return None
 
     try:
         # LC_MESSAGES to get English output, 2>/dev/null to
         # prevent output on stderr
-        cmd = 'LC_MESSAGES=C %s %s 2>/dev/null' % (executable, args)
+        cmd = 'LC_ALL=C %s %s 2>/dev/null' % (executable, args)
         with os.popen(cmd) as pipe:
             for line in pipe:
                 words = line.lower().split()
@@ -305,9 +305,9 @@
 
     try:
-        # LC_MESSAGES to get English output, 2>/dev/null to
+        # LC_ALL to ensure English output, 2>/dev/null to
         # prevent output on stderr